==> worker_2.19.2.orig.tar.bz2: worker-2.19.2/src/shortkeyfromlistop.h <==
/* shortkeyfromlistop.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001-2004 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
/* $Id: shortkeyfromlistop.h,v 1.6 2005/10/19 18:01:31 ralf Exp $ */

#ifndef SHORTKEYFROMLIST_H
#define SHORTKEYFROMLIST_H

#include "wdefines.h"
#include "functionproto.h"

class ShortkeyFromListOp:public FunctionProto
{
public:
  ShortkeyFromListOp();
  virtual ~ShortkeyFromListOp();
  ShortkeyFromListOp( const ShortkeyFromListOp &other );
  ShortkeyFromListOp &operator=( const ShortkeyFromListOp &other );

  virtual ShortkeyFromListOp *duplicate() const;
  virtual bool isName(const char *);
  virtual const char *getName();
#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
  using FunctionProto::run;
#endif
  virtual int run( WPUContext *wpu, ActionMessage* );
  virtual const char *getDescription();
protected:
  static const char *name;
  // Infos to save

  // temp variables
  Lister *startlister;
};

#endif

==> worker_5.3.1.orig.tar.bz2: worker-5.3.1/src/shortkeyfromlistop.h <==
/* shortkeyfromlistop.h
 * This file belongs to Worker, a file manager for UN*X/X11.
 * Copyright (C) 2001-2021 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
/* $Id: shortkeyfromlistop.h,v 1.6 2005/10/19 18:01:31 ralf Exp $ */

#ifndef SHORTKEYFROMLIST_H
#define SHORTKEYFROMLIST_H

#include "wdefines.h"
#include "functionproto.h"

class ShortkeyFromListOp:public FunctionProto
{
public:
  ShortkeyFromListOp();
  virtual ~ShortkeyFromListOp();
  ShortkeyFromListOp( const ShortkeyFromListOp &other );
  ShortkeyFromListOp &operator=( const ShortkeyFromListOp &other );

  ShortkeyFromListOp *duplicate() const override;
  bool isName(const char *) override;
  const char *getName() override;
  int run( std::shared_ptr< WPUContext > wpu, ActionMessage* ) override;
  const char *getDescription() override;
protected:
  static const char *name;
  // Infos to save

  // temp variables
  Lister *startlister;
};

#endif
